Changelog
===========

All notable changes to this project are documented here.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

v0.1.0 (2024-04-08)
---------------------

Added
^^^^^^
- First public release of Langformers.
- Core NLP pipelines.
- Documentation and README.md.